.. _usage:

##################
Usage instructions
##################

In this section you can find some advice how to use AROSICS for the detection and correction
of misregistrations locally or globally present in your input data.


.. todo::

   This section is not yet complete but will be continously updated in future.
   If you miss topics, feel free to suggest new entries here!


.. toctree::
    :maxdepth: 4

    usage/input_data_requirements.rst
    usage/global_coreg.rst
    usage/local_coreg.rst


.. seealso::

    For details regarding the implemented algorithm, example use cases, quality assessment and benchmarks
    refer to the (open-access) paper about AROSICS:
    `Scheffler et al. 2017 <http://www.mdpi.com/2072-4292/9/7/676>`__
